@@ -11,7 +11,7 @@ use Exporter qw(import);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2025-09-24'; # DATE
 our $DIST = 'Number-Format-Metric'; # DIST
-our $VERSION = '0.603'; # VERSION
+our $VERSION = '0.604'; # VERSION
 
 our @EXPORT_OK = qw(
                        format_metric
@@ -81,7 +81,7 @@ Number::Format::Metric - Format number with metric prefix, with some options
 
 =head1 VERSION
 
-This document describes version 0.603 of Number::Format::Metric (from Perl distribution Number-Format-Metric), released on 2025-09-24.
+This document describes version 0.604 of Number::Format::Metric (from Perl distribution Number-Format-Metric), released on 2025-09-24.
 
 =head1 SYNOPSIS
 
@@ -159,8 +159,27 @@ Source repository is at L<https://github.com/perlancar/perl-Number-Format-Metric
 
 =head1 SEE ALSO
 
-Other number formatting modules: L<Number::Format>, L<Format::Human::Bytes>,
-L<Number::Bytes::Human>.
+=head2 Unformatting numbers
+
+L<Data::Sah::Coerce> coerce module:
+L<Data::Sah::Coerce::perl::To_float::From_str::suffix_datasize> and
+L<Data::Sah::Coerce::perl::To_float::From_str::suffix_datasize>. Example of
+using this can be seen in L<datasize-from-metric> and L<dataspeed-from-metric>
+(included in the L<App::DataSizeSpeedUtils> distribution).
+
+=head2 Other number formatting modules
+
+L<Number::Format> can format several kinds of numbers e.g. bytes ("2.3KB") or
+prices ("USD 5,000") as well as format using template ("picture") like
+`sprintf`. But for metric prefixes it only supports kilo, kibi, mega, mebi,
+giga, gibi. It can also unformat numbers back to floating point form.
+
+L<Format::Human::Bytes> supports formatting bytes with prefixes kilo, mega,
+giga, and tera.
+
+L<Number::Bytes::Human> supports formatting with prefixes kilo (2^10) to yotta
+(2^70), but does not support smaller prefixes, e.g. milli, micro, etc.
+Obviously.
 
 L<https://en.wikipedia.org/wiki/Metric_prefix>
 
